"""
.. module:: views
   :synopsis: flask views for demo and api.

.. moduleauthor:: Jai Chaudhary <jai.chaudhary.iitd@gmail.com>


"""

from flask import render_template
from flask import request
from flask import jsonify
from piglatintranslation import app

from .pig_latin_translation import translate_text

@app.route('/', methods=['GET','POST'])
@app.route('/index', methods=['GET','POST'])
def index():
    if request.method == "POST" and request.form['text'] != "":
        return render_template('index.html',
            default_text=request.form['text'],
            translation=translate_text(request.form['text']))

    return render_template('index.html',
        default_text='Where is the toilet?',
        translation='None')

@app.route('/api/translate', methods=['POST'])
def translate():
    return jsonify({
        'text' : translate_text(request.form['text']),})


import os
from setuptools import setup

def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()


setup(
    name='PigLatinTranslation',
    version='0.1.5',
    include_package_data=True,
    zip_safe=False,
    url='https://github.com/Jai-Chaudhary/pig-latin-translation-microservice',
    license='MIT',
    author='Jai Chaudhary',
    author_email='jai.chaudhary.ittd@gmail.com',
    packages=['piglatintranslation',],
    install_requires=['Flask'],
    long_description=read('README.md'),
    description='A Pig Latin Translation Microservice',
    classifiers=[
      "Development Status :: 3 - Alpha",
    ]
)